@@ -9,6 +9,9 @@ from utils import base_parser as _base_parser
 from utils import get_s3_connection_host
 
 
+env.use_ssh_config = True
+
+
 def run_backup(args):
     if args.user:
         env.user = args.user
@@ -16,7 +19,10 @@ def run_backup(args):
     if args.password:
         env.password = args.password
 
-    env.hosts = sorted(args.hosts.split(','))
+    if args.sshport:
+        env.port = args.sshport
+
+    env.hosts = args.hosts.split(',')
 
     if args.new_snapshot:
         create_snapshot = True
@@ -143,7 +149,10 @@ def main():
                                help='cassandra binaries directory')
 
     backup_parser.add_argument('--user',
-                               help='the ssh user to loging on nodes')
+                               help='the ssh user to logging on nodes')
+
+    backup_parser.add_argument('--sshport',
+                               help='the ssh port to use to connect to the nodes')
 
     backup_parser.add_argument('--password',
                                 default='',
